MCPcopy Create free account
hub / github.com/ROCm/rocPRIM / increment_kernel

Function increment_kernel

test/hip/test_hip_async_copy.cpp:84–92  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

82
83template<class T>
84__global__
85void increment_kernel(T* const d_input, const size_t size)
86{
87 const unsigned int id = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
88 if(id < size)
89 {
90 d_input[id] += static_cast<T>(1);
91 }
92}
93
94} // namespace
95

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected